==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.NetworkApiVersion
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile.
 * @property healthProbe A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
 * @property networkApiVersion specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
 * @property networkInterfaceConfigurations The list of network configurations.
 */
public data class VirtualMachineScaleSetNetworkProfileArgs(
    public val healthProbe: Output<ApiEntityReferenceArgs>? = null,
    public val networkApiVersion: Output<Either<String, NetworkApiVersion>>? = null,
    public val networkInterfaceConfigurations:
    Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs.builder()
            .healthProbe(healthProbe?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .networkApiVersion(
                networkApiVersion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .networkInterfaceConfigurations(
                networkInterfaceConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkProfileArgsBuilder internal constructor() {
    private var healthProbe: Output<ApiEntityReferenceArgs>? = null

    private var networkApiVersion: Output<Either<String, NetworkApiVersion>>? = null

    private var networkInterfaceConfigurations:
        Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>? = null

    /**
     * @param value A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("tuhesmdadignelra")
    public suspend fun healthProbe(`value`: Output<ApiEntityReferenceArgs>) {
        this.healthProbe = value
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("nqkymlmhrbdvmqlk")
    public suspend fun networkApiVersion(`value`: Output<Either<String, NetworkApiVersion>>) {
        this.networkApiVersion = value
    }

    /**
     * @param value The list of network configurations.
     */
    @JvmName("sybcttpdgoepcieb")
    public suspend
    fun networkInterfaceConfigurations(`value`: Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>) {
        this.networkInterfaceConfigurations = value
    }

    @JvmName("hpwynlpmxfogtnkw")
    public suspend fun networkInterfaceConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetNetworkConfigurationArgs>,
    ) {
        this.networkInterfaceConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of network configurations.
     */
    @JvmName("xvkvfvcuwbisimoe")
    public suspend
    fun networkInterfaceConfigurations(values: List<Output<VirtualMachineScaleSetNetworkConfigurationArgs>>) {
        this.networkInterfaceConfigurations = Output.all(values)
    }

    /**
     * @param value A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("sskoxgirurxfcxmc")
    public suspend fun healthProbe(`value`: ApiEntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.healthProbe = mapped
    }

    /**
     * @param argument A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("vmlaeayxonbhhden")
    public suspend fun healthProbe(argument: suspend ApiEntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ApiEntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.healthProbe = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("prinvrssfdgymkqb")
    public suspend fun networkApiVersion(`value`: Either<String, NetworkApiVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("tkyuugdsrnwvtgml")
    public fun networkApiVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkApiVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("eomolywugslsvptf")
    public fun networkApiVersion(`value`: NetworkApiVersion) {
        val toBeMapped = Either.ofRight<String, NetworkApiVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value The list of network configurations.
     */
    @JvmName("linjkynedjnnxtot")
    public suspend
    fun networkInterfaceConfigurations(`value`: List<VirtualMachineScaleSetNetworkConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("xvyhfsxyuwoaprcm")
    public suspend
    fun networkInterfaceConfigurations(argument: List<suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("mcmpqofifmymtrbg")
    public suspend fun networkInterfaceConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("qetaqpduhjemphlh")
    public suspend
    fun networkInterfaceConfigurations(argument: suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param values The list of network configurations.
     */
    @JvmName("fhmrbxqtmjcboihb")
    public suspend fun networkInterfaceConfigurations(
        vararg
        values: VirtualMachineScaleSetNetworkConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaceConfigurations = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkProfileArgs =
        VirtualMachineScaleSetNetworkProfileArgs(
            healthProbe = healthProbe,
            networkApiVersion = networkApiVersion,
            networkInterfaceConfigurations = networkInterfaceConfigurations,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.NetworkApiVersion
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile.
 * @property healthProbe A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
 * @property networkApiVersion specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
 * @property networkInterfaceConfigurations The list of network configurations.
 */
public data class VirtualMachineScaleSetNetworkProfileArgs(
    public val healthProbe: Output<ApiEntityReferenceArgs>? = null,
    public val networkApiVersion: Output<Either<String, NetworkApiVersion>>? = null,
    public val networkInterfaceConfigurations:
    Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkProfileArgs.builder()
            .healthProbe(healthProbe?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .networkApiVersion(
                networkApiVersion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .networkInterfaceConfigurations(
                networkInterfaceConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkProfileArgsBuilder internal constructor() {
    private var healthProbe: Output<ApiEntityReferenceArgs>? = null

    private var networkApiVersion: Output<Either<String, NetworkApiVersion>>? = null

    private var networkInterfaceConfigurations:
        Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>? = null

    /**
     * @param value A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("thgwcggbejwmdxyn")
    public suspend fun healthProbe(`value`: Output<ApiEntityReferenceArgs>) {
        this.healthProbe = value
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("wxsoypbcvsunyoof")
    public suspend fun networkApiVersion(`value`: Output<Either<String, NetworkApiVersion>>) {
        this.networkApiVersion = value
    }

    /**
     * @param value The list of network configurations.
     */
    @JvmName("pxcsxouyspukvuyw")
    public suspend
    fun networkInterfaceConfigurations(`value`: Output<List<VirtualMachineScaleSetNetworkConfigurationArgs>>) {
        this.networkInterfaceConfigurations = value
    }

    @JvmName("qywsvqqlaqfudxom")
    public suspend fun networkInterfaceConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetNetworkConfigurationArgs>,
    ) {
        this.networkInterfaceConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of network configurations.
     */
    @JvmName("elrnaitjrhhitvwb")
    public suspend
    fun networkInterfaceConfigurations(values: List<Output<VirtualMachineScaleSetNetworkConfigurationArgs>>) {
        this.networkInterfaceConfigurations = Output.all(values)
    }

    /**
     * @param value A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("hntyrrwhppofjaug")
    public suspend fun healthProbe(`value`: ApiEntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.healthProbe = mapped
    }

    /**
     * @param argument A reference to a load balancer probe used to determine the health of an instance in the virtual machine scale set. The reference will be in the form: '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
     */
    @JvmName("dlwghvgroubyiumi")
    public suspend fun healthProbe(argument: suspend ApiEntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ApiEntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.healthProbe = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("wqfssgmooudxveyr")
    public suspend fun networkApiVersion(`value`: Either<String, NetworkApiVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("npcahetdxqccevto")
    public fun networkApiVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkApiVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value specifies the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'
     */
    @JvmName("xbfbcaispbfifdlb")
    public fun networkApiVersion(`value`: NetworkApiVersion) {
        val toBeMapped = Either.ofRight<String, NetworkApiVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkApiVersion = mapped
    }

    /**
     * @param value The list of network configurations.
     */
    @JvmName("fkqpniwubkykcanh")
    public suspend
    fun networkInterfaceConfigurations(`value`: List<VirtualMachineScaleSetNetworkConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("fetexeepywdysdje")
    public suspend
    fun networkInterfaceConfigurations(argument: List<suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("bepujteipdafugpn")
    public suspend fun networkInterfaceConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param argument The list of network configurations.
     */
    @JvmName("qxxswfhdbjjhxfgo")
    public suspend
    fun networkInterfaceConfigurations(argument: suspend VirtualMachineScaleSetNetworkConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetNetworkConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.networkInterfaceConfigurations = mapped
    }

    /**
     * @param values The list of network configurations.
     */
    @JvmName("itxqggheoggtigqy")
    public suspend fun networkInterfaceConfigurations(
        vararg
        values: VirtualMachineScaleSetNetworkConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaceConfigurations = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkProfileArgs =
        VirtualMachineScaleSetNetworkProfileArgs(
            healthProbe = healthProbe,
            networkApiVersion = networkApiVersion,
            networkInterfaceConfigurations = networkInterfaceConfigurations,
        )
}
